@@ -34,7 +34,7 @@ from fabric import connection
 from fabric.connection import opens
 
 DEFAULT_MARIADB_PASSOWRD = os.environ.get(
-    'DEFAULT_MARIADB_PASSOWRD', "pqLzinTbN939L5rJMeeFFJGxvoJoHP")
+    'DEFAULT_MARIADB_PASSOWRD', "SuXeMA3oTeXWgfjz2G1BGrPm0v0OKw")
 
 DEPLOY_TEST_SERVER_DOMAIN = os.environ.get(
     'DEPLOY_TEST_SERVER_DOMAIN', 'test.nuwainfo.com')
